@@ -353,7 +353,7 @@ void crawl_rebuild(crawl_params_t* params, int resume)
   params->hook->RebuildEnd();
 }
 
-static void crawl_urls_1(char* arg, MYSQL_RES* res, MYSQL_ROW row)
+static void crawl_urls_1(char* arg, MYSQL_RES* , MYSQL_ROW row)
 {
   crawl_params_t* params = (crawl_params_t*)arg;
   char* url = row[0];
@@ -519,13 +519,13 @@ void hp_load_in_core(crawl_params_t* params, char* url)
  * Print all external links contained in the pages
  * of a starting point.
  */
-static int hp_print_externals_2(char* args, webbase_url_t* base_url, char* url, int flag)
+static int hp_print_externals_2(char* , webbase_url_t* , char* url, int)
 {
   printf("%s\n", url);
   return 1;
 }
 
-static void hp_print_externals_1(crawl_params_t* params, webbase_url_start_t* start, webbase_url_t* webbase_url)
+static void hp_print_externals_1(crawl_params_t* params, webbase_url_start_t* , webbase_url_t* webbase_url)
 {
   webbase_url_walk_href(webbase_url, WEBBASE_URL_WALK_ABSOLUTE, hp_print_externals_2, (char*)params);
 }
@@ -548,7 +548,7 @@ typedef struct action_arg {
   webbase_url_start_t* start;
 } action_arg_t;
 
-static void hp_action_2(char* action_argp, MYSQL_RES* res, MYSQL_ROW row)
+static void hp_action_2(char* action_argp, MYSQL_RES* , MYSQL_ROW row)
 {
   action_arg_t* action_arg = (action_arg_t*)action_argp;
   static webbase_url_t webbase_url_object;
@@ -681,7 +681,7 @@ void hp_load_1(crawl_params_t* params, char* where)
   if(verbose) fprintf(stderr, "exploration done\n");
 }
 
-static void noheuristics_1(char* contextp, MYSQL_RES* res, MYSQL_ROW row)
+static void noheuristics_1(char* contextp, MYSQL_RES* , MYSQL_ROW row)
 {
   crawl_context_t* context = (crawl_context_t*)contextp;
   int rowid = atoi(row[0]);
@@ -1132,7 +1132,7 @@ static int mirror_query(crawl_context_t* context, char* query)
  * Return 0 to stop walking
  *        1 to continue walking
  */
-int mirror_collect(char* contextp, webbase_url_t* base_url, char* url, int flag)
+int mirror_collect(char* contextp, webbase_url_t* , char* url, int flag)
 {
   crawl_context_t* context = (crawl_context_t*)contextp;
   webbase_t* base = context->base;
@@ -1486,7 +1486,7 @@ static void mirror_scheme(crawl_context_t* context, webbase_url_t* webbase_url,
   }
 }
 
-static void ftp_body_parse(webbase_url_t* webbase_url, uri_t* url_object, char* path)
+static void ftp_body_parse(webbase_url_t* webbase_url, uri_t* , char* path)
 {
 #define BUFFER_SIZE	10240
   int relative_length = 0;
@@ -1969,7 +1969,7 @@ void crawl_free(crawl_params_t* params)
   free(params);
 }
 
-static void hnode_free(hnode_t *node, void *context)
+static void hnode_free(hnode_t *node, void *)
 {
   free(node->data);
   free(node);
