@@ -22,10 +22,6 @@
 #include <webbase_url.h>
 #include <cookies.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 typedef struct http_context {
   webbase_url_t* webbase_url;
   cookies_t* cookies;
@@ -35,8 +31,4 @@ int http_header(char* arg, int sd, char* buffer, int buffer_size, int flag);
 int http_body(char* arg, int sd, char* buffer, int buffer_size, int flag);
 void http_verbose(int level);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _http_h */
