@@ -66,7 +66,7 @@ static struct option long_options[] =
   {0, 0, 0, WEBBASE_OPTIONS}
 };
 
-struct option* webbase_options(struct option options[])
+struct option* webbase_options(struct option [])
 {
   return long_options;
 }
@@ -233,7 +233,7 @@ void webbase_free(webbase_t* base)
   free(base);
 }
 
-void webbase_lock_ignore(webbase_t* base, int varint, char* varchar)
+void webbase_lock_ignore(webbase_t*, int varint, char* varchar)
 {
   static char name[512];
 
@@ -385,7 +385,7 @@ void webbase_unlock(webbase_t* base, int varint, char* varchar)
 /*
  * start functions
  */
-void webbase_default_start(webbase_t* base, webbase_url_start_t* start)
+void webbase_default_start(webbase_t*, webbase_url_start_t* start)
 {
   start->url_max_size = WEBBASE_URL_START_DEFAULT_URL_MAX_SIZE;
   start->size_limit = WEBBASE_URL_START_DEFAULT_SIZE_LIMIT;
@@ -1058,7 +1058,7 @@ int webbase_visited(webbase_t* base, char* url)
   return rowid;
 }
 
-static webbase_url_t* webbase_decode_url(webbase_t* base, MYSQL_RES *res, MYSQL_ROW row, webbase_url_t* webbase_url)
+static webbase_url_t* webbase_decode_url(webbase_t* , MYSQL_RES *res, MYSQL_ROW row, webbase_url_t* webbase_url)
 {
   unsigned int i;
   /*
@@ -1233,7 +1233,7 @@ int webbase_counted(webbase_t* base, webbase_url_start_t* start, int rowid)
   return num_rows;
 }
 
-static void hnode_free(hnode_t *node, void *context)
+static void hnode_free(hnode_t *node, void *)
 {
   free(node->data);
   free(node);
