@@ -32,10 +32,6 @@
 
 #include <md5str.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #define WEBBASE_URL_LENGTH		512
 #define WEBBASE_CONTENT_TYPE_LENGTH	32
 #define WEBBASE_LANGUAGE_LENGTH		10
@@ -317,8 +313,4 @@ void webbase_url_hrefs_set(webbase_url_t* webbase_url, char* path, int size_limi
 void webbase_url_print(webbase_url_t* webbase_url);
 void webbase_url_mtime_fix(webbase_url_t* webbase_url);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _webbase_url_h */
