@@ -89,7 +89,7 @@ static struct option long_options[] =
 
 struct sigaction action_timeout_firewall;
 
-struct option* webtools_options(struct option options[])
+struct option* webtools_options(struct option [])
 {
   return long_options;
 }
@@ -142,7 +142,7 @@ webtools_params_t* webtools_alloc(int argc, char** argv, struct option options[]
   return params;
 }
 
-void hand_timeout_firewall(int sig) {
+void hand_timeout_firewall(int ) {
   
 }
 
@@ -166,7 +166,7 @@ int webtools_open(webtools_params_t* params, char* host, char* port)
   return webtools_open_1(params, *(struct in_addr*)hostent->h_addr_list[0], atoi(port));
 }
 
-int webtools_write(webtools_params_t* params, int sd, char* buffer, int size)
+int webtools_write(webtools_params_t* , int sd, char* buffer, int size)
 {
   return write(sd, buffer, size);
 }
@@ -346,7 +346,7 @@ static int webtools_reader_http_body(webtools_params_t* params, int sd, struct w
 
 #define TIMEOUT_FIREWALL 60
 
-static int webtools_open_1(webtools_params_t* params, struct in_addr server, short port)
+static int webtools_open_1(webtools_params_t* , struct in_addr server, short port)
 {
   struct sockaddr_in sin;
   int sd;
@@ -387,7 +387,7 @@ static int webtools_open_1(webtools_params_t* params, struct in_addr server, sho
   return sd;
 }
 
-static void hnode_free(hnode_t *node, void *context)
+static void hnode_free(hnode_t *node, void *)
 {
   free(node->data);
   free(node);
