@@ -72,14 +72,16 @@ WebbaseHookMifluz::WebbaseHookMifluz()
     { "wordlist_extend", "true", 0 },
     { "minimum_word_length", "1", 0 },
     { "maximum_word_length", "25", 0 },
-    { "wordlist_cache_size", "10000000", 0 }, // 10Mb
+    { "wordlist_cache_size", "100000000", 0 }, // 10Mb
     { "wordlist_page_size", "4096", 0 },     // 32Kb
     { "wordlist_compress", "1", 0 },
     { "wordlist_wordkey_description","nfields: 5/URL 32 2/Location 16 4/Server 19 1/Tag 5 3/Word 0 0"},
-//     { "wordlist_monitor","true"},
-//     { "wordlist_monitor_period","10.0"},
-//     { "wordlist_monitor_input","true" },
+#if 0
+    { "wordlist_monitor","true"},
+    { "wordlist_monitor_period","10.0"},
+    { "wordlist_monitor_input","true" },
     { "wordlist_compress_debug", "0"},
+#endif
     { 0, 0, 0 }
   };
 
@@ -314,6 +316,7 @@ int WebbaseHookMifluz::InsertContent(const char* buffer, int buffer_length)
     word_start = p;
   }
 
+  free((void *)buffer_tmp);
   return 1;
 }
 
