@@ -19,7 +19,15 @@
 #ifndef _read_file_h
 #define _read_file_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char* read_file(char* path, int* size);
 char* read_file_1(char* path, int* size);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* read_file_h */
